/*
Copyright 2022 CAcert Inc.
SPDX-License-Identifier: Apache-2.0

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package command

import (
	"math/big"

	"git.cacert.org/cacert-gosigner/pkg/messages"
	"git.cacert.org/cacert-gosigner/pkg/protocol"
)

func CAInfo(caName string) *protocol.Command {
	return &protocol.Command{
		Announce: messages.BuildCommandAnnounce(messages.CmdCAInfo),
		Command:  &messages.CAInfoCommand{Name: caName},
	}
}

func FetchCRL(caName string, crlNumber *big.Int) *protocol.Command {
	var lastKnown []byte

	if crlNumber != nil {
		lastKnown = crlNumber.Bytes()
	}

	return &protocol.Command{
		Announce: messages.BuildCommandAnnounce(messages.CmdFetchCRL),
		Command: &messages.FetchCRLCommand{
			IssuerID:    caName,
			LastKnownID: lastKnown,
		},
	}
}

func Health() *protocol.Command {
	return &protocol.Command{
		Announce: messages.BuildCommandAnnounce(messages.CmdHealth),
		Command:  &messages.HealthCommand{},
	}
}
